@@ -1,29 +1,26 @@
-/***************************************************************************
- *   Copyright © 2011 Jonathan Thomas <echidnaman@kubuntu.org>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2011 Jonathan Thomas <echidnaman@kubuntu.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "Review.h"
 #include <resources/ResourcesModel.h>
 
-Review::Review(QString  name, QString  pkgName, QString  language, QString  summary,
-               QString  reviewText, QString  userName, const QDateTime& date, bool show, quint64 id,
-               int rating, int usefulTotal, int usefulFavorable, QString  packageVersion)
+Review::Review(QString name,
+               QString pkgName,
+               QString language,
+               QString summary,
+               QString reviewText,
+               QString userName,
+               const QDateTime &date,
+               bool show,
+               quint64 id,
+               int rating,
+               int usefulTotal,
+               int usefulFavorable,
+               qreal wilsonScore,
+               QString packageVersion)
     : m_appName(std::move(name))
     , m_creationDate(date)
     , m_shouldShow(show)
@@ -35,10 +32,12 @@ Review::Review(QString  name, QString  pkgName, QString  language, QString  summ
     , m_reviewer(std::move(userName))
     , m_usefulnessTotal(usefulTotal)
     , m_usefulnessFavorable(usefulFavorable)
+    , m_wilsonScore(wilsonScore)
     , m_usefulChoice(ReviewsModel::None)
     , m_summary(std::move(summary))
     , m_packageVersion(std::move(packageVersion))
-{}
+{
+}
 
 Review::~Review() = default;
 
@@ -117,6 +116,11 @@ int Review::usefulnessFavorable() const
     return m_usefulnessFavorable;
 }
 
+qreal Review::wilsonScore() const
+{
+    return m_wilsonScore;
+}
+
 ReviewsModel::UserChoice Review::usefulChoice() const
 {
     return m_usefulChoice;
