@@ -16,8 +16,8 @@
 #include <resources/ResourcesProxyModel.h>
 #include <resources/ResourcesUpdatesModel.h>
 
+#include <QSignalSpy>
 #include <QTest>
-#include <QtTest>
 
 class UpdateDummyTest : public QObject
 {
@@ -25,8 +25,8 @@ class UpdateDummyTest : public QObject
 public:
     AbstractResourcesBackend *backendByName(ResourcesModel *m, const QString &name)
     {
-        QVector<AbstractResourcesBackend *> backends = m->backends();
-        foreach (AbstractResourcesBackend *backend, backends) {
+        const QVector<AbstractResourcesBackend *> backends = m->backends();
+        for (AbstractResourcesBackend *backend : backends) {
             if (QLatin1String(backend->metaObject()->className()) == name) {
                 return backend;
             }
