@@ -5,7 +5,8 @@
  */
 
 #include "LocalFilePKResource.h"
-#include "libdiscover_backend_debug.h"
+#include "libdiscover_backend_packagekit_debug.h"
+
 #include <PackageKit/Daemon>
 #include <PackageKit/Details>
 #include <QDebug>
@@ -43,8 +44,9 @@ QString LocalFilePKResource::origin() const
 
 void LocalFilePKResource::fetchDetails()
 {
-    if (!m_details.isEmpty())
+    if (!m_details.isEmpty()) {
         return;
+    }
     m_details.insert(QStringLiteral("fetching"), true); // we add an entry so it's not re-fetched.
 
     if (PackageKit::Daemon::roles() & PackageKit::Transaction::RoleGetDetailsLocal) {
@@ -68,7 +70,7 @@ void LocalFilePKResource::fetchDetails()
                     m_exec.prepend(QLatin1Char('/'));
                 }
             } else {
-                qWarning() << "could not find an executable desktop file for" << m_path << "among" << files;
+                qCWarning(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG) << "could not find an executable desktop file for" << m_path << "among" << files;
             }
         });
     }
@@ -78,17 +80,19 @@ void LocalFilePKResource::resolve(const PackageKit::Details &inDetails)
 {
     clearPackageIds();
     const PackageKit::Details details = inDetails.isEmpty() ? m_details : inDetails;
-    PackageKit::Transaction *resolve = PackageKit::Daemon::resolve(PackageKit::Daemon::packageName(details.packageId()), PackageKit::Transaction::FilterNone);
-    connect(resolve, &PackageKit::Transaction::package, this, [this, details](PackageKit::Transaction::Info info, const QString &packageId) {
-        if (PackageKit::Daemon::packageName(packageId) == PackageKit::Daemon::packageName(details.packageId())
-            && PackageKit::Daemon::packageVersion(packageId) == PackageKit::Daemon::packageVersion(details.packageId())
-            && PackageKit::Daemon::packageArch(packageId) == PackageKit::Daemon::packageArch(details.packageId())
+    const auto detailsPackageId = details.packageId();
+    auto resolve = PackageKit::Daemon::resolve(PackageKit::Daemon::packageName(detailsPackageId), PackageKit::Transaction::FilterNone);
+
+    connect(resolve, &PackageKit::Transaction::package, this, [this, detailsPackageId](PackageKit::Transaction::Info info, const QString &packageId) {
+        if (PackageKit::Daemon::packageName(packageId) == PackageKit::Daemon::packageName(detailsPackageId)
+            && PackageKit::Daemon::packageVersion(packageId) == PackageKit::Daemon::packageVersion(detailsPackageId)
+            && PackageKit::Daemon::packageArch(packageId) == PackageKit::Daemon::packageArch(detailsPackageId)
             && info == PackageKit::Transaction::InfoInstalled) {
             addPackageId(info, packageId, true);
         }
     });
-    connect(resolve, &PackageKit::Transaction::finished, this, [this, details] {
-        addPackageId(PackageKit::Transaction::InfoAvailable, details.packageId(), true);
+    connect(resolve, &PackageKit::Transaction::finished, this, [this, details, detailsPackageId] {
+        addPackageId(PackageKit::Transaction::InfoAvailable, detailsPackageId, true);
         PackageKitResource::setDetails(details);
     });
 }
@@ -103,3 +107,5 @@ void LocalFilePKResource::invokeApplication() const
 
     runService(service);
 }
+
+#include "moc_LocalFilePKResource.cpp"
